**********************************************************************
How to create and maintain a Python package using the Astropy template
**********************************************************************

The Astropy template is pending deprecation in favor of
|OpenAstronomy Packaging Guide|.


.. _simple-release-docs:

Releasing a Python package
**************************

Please see the "Releasing Your Package" section in the
|OpenAstronomy Packaging Guide|.
